@@ -77,19 +77,21 @@ class Builder:
         self.loadtypes = {}
         self.loadtypes['json'] = read_json
         self.loadtypes['confz'] = read_confz
-    def add_file(self, filepath, format = None):
+    def add_file(self, filepath, format = None, update = False):
         if format is None:
             format = self.format
         obj = self.loadtypes[format](filepath)
-        self.add(obj)
-    def add(self, data):
+        self.add(obj, update)
+    def add(self, data, update = False):
         if type(data) == dict:
             data = [data]
         for obj in data:
             key = get(obj, "key")
-            if key in self.maps:
+            if key in self.maps and not update:
                 raise Exception("duple define key: ["+key+"]")
             self.maps[key] = obj
+            if update and key in self.objs:
+                del self.objs[key]
     def get_this(self, key, obj):
         return getattr(obj, key)
     def deal_args(self, args, obj = None):
@@ -127,6 +129,9 @@ class Builder:
             self.types[call[1]](call[0], obj)
     def get(self, key, src = None, force_new = False):
         return self.run(key, src, force_new)
+    def set(self, key, val):
+        self.maps[key] = {"single":"1"}
+        self.objs[key] = val
     def run(self, key, src = None, force_new = False):
         if self.ref_this is not None and key == self.ref_this:
             return self
@@ -216,7 +221,7 @@ def main(paths, default_import = g_default_import, ref_this = "this"):
         if os.path.isfile(path):
             builder.add_file(path)
         elif os.path.isdir(path):
-            files = os.listdirs(path)
+            files = os.listdir(path)
             files = [os.path.join(path, file) for file in files]
             [builder.add_file(file) for file in files]
         else:
